//******************************************************************************
//  MSP-FET430P140 Demo - ADC12, Using an External Reference
//
//  Description: This example shows how to use an external positive reference 
//  for the ADC12. The external reference is applied to the VeREF+ pin. AVss is 
//  used for the negative reference. A single conversion is performed on channel
//  A0. The conversion results are stored in ADC12MEM0. Test by applying a 
//  voltage to channel A0, then setting and running to a break point at the 
//  "_NOP()" instruction. To view the conversion results, open an SFR window in 
//  the debugger and view the contents of ADC12MEM0.
//
//                   MSP430F149
//                ---------------
//               |               |
//        Vin -->|P6.0/A0        |
//               |               |
//        REF -->|VeREF+         |
//               |               |
//
//  M. Mitchell / G. Morton
//  Texas Instruments Inc.
//  May 2005
//  Built with Code Composer Essentials Version: 1.0
//******************************************************************************

#include  <msp430x14x.h>

void main(void)
{
  WDTCTL = WDTPW+WDTHOLD;                   // Stop watchdog timer
  P6SEL |= 0x01;                            // Enable A/D channel A0
  ADC12CTL0 = ADC12ON+SHT0_2;               // Turn on ADC12, set sampling time
  ADC12CTL1 = SHP;                          // Use sampling timer
  ADC12MCTL0 = SREF_2;                      // Vr+ = VeREF+ (external)
  ADC12CTL0 |= ENC;                         // Enable conversions

  while (1)
  {
    ADC12CTL0 |= ADC12SC;                   // Start conversion
    while ((ADC12IFG & BIT0)==0);
    _NOP();                                 // SET BREAKPOINT HERE
  }
}